#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"

usage()
{
cat << EOF
usage: $0 -d <db> -o <dir> [-s <n>] 

The script runs TPC-H ACID Durability Tests AFTER the failure

OPTIONS:
    -h              show this message  
    -d  <database>  database name  
    -s  <number>    number of streams (default=2)
    -o  <dir>       output directory where pre-failure durability
                    tests output were stored.    
EOF
}

STREAMS=2
OUTPUT_DIR=
DATABASE=
while getopts "d:s:o:" opt; do
    case $opt in
        d)
            DATABASE=$OPTARG
            ;;    	
        s)
        	STREAMS=$OPTARG
        	;;
        o)
        	OUTPUT_DIR=$OPTARG
        	;;            
        ?)
            usage
            exit 1
            ;;
    esac
done

if [ -z "$DATABASE" ]; then
	usage
	exit 1
fi

if [ -z "$OUTPUT_DIR" ]; then
	usage
	exit 1
fi

if [ ! -e "$OUTPUT_DIR" ]; then
	echo "Error: $OUTPUT_DIR directory does not exist"
fi

if [ $STREAMS -lt 2 ]; then
	echo "Error: Number of streams must be >= 2"
	exit 1
fi

echo "====================================="
echo "TPC-H Durability Tests * POST-FAILURE"
echo "====================================="
echo "Test Started at: `date`"
echo

# gather all success records generated by streams into one file called SUCCESS_FILE
#
rm -rf $OUTPUT_DIR/SUCCESS_FILE

for ((i=0;i<${STREAMS};i++)); do
	cat $OUTPUT_DIR/step2_stream${i}_output | grep success_record | awk '{printf("%s %s %s %s %s %s %s\n",$2, $3, $4, $5, $6, $7, $8);}' >> $OUTPUT_DIR/SUCCESS_FILE
done

echo
echo "SUCCESS FILE: $OUTPUT_DIR/SUCCESS_FILE"
echo

###################
# STEP 5
###################
echo
echo ">>> STEP 5"
echo

# Count number fo records in the sucess file
#
COUNT_SUCCESS=`cat $OUTPUT_DIR/SUCCESS_FILE | wc -l`
echo "  Number of records in the Success File  = $COUNT_SUCCESS"

# Count the number of records in the HISTORY table.
# Note that the HISTORY table was recreated at the beginning
# of the Durability test (see dur.sh)
#
echo "select * from HISTORY;\p\g" | sql $DATABASE > $OUTPUT_DIR/POST_FAILURE_HISTORY_TABLE
COUNT_HISTORY=`cat $OUTPUT_DIR/POST_FAILURE_HISTORY_TABLE | grep '(* row[s]*)' | sed 's/[()]//g'`
echo "  Number of records in the HISTORY table = $COUNT_HISTORY"

echo
echo "STEP 5 COMPLETED."
echo

###################
# STEP 6
###################
echo
echo ">>> STEP 6"
echo

# Using the KEYS collected in STEP 1, re-verify the consistency 
#
echo "Re-verifying consistency..."
for ((i=0;i<${STREAMS};i++)); do
	KEYS=`head -n 10 $OUTPUT_DIR/stream${i}_rnd | awk '{printf "%d ", $1}'`
			
	for j in $KEYS; do
		$IVWDIR/acid/cons/consist_condition -b $DATABASE -o ${j} >> $OUTPUT_DIR/step6_stream${i}_output
	done
	echo "	output for stream ${i} in $OUTPUT_DIR/step6_stream${i}_output"
done

echo
echo "STEP 6 COMPLETED."
echo

echo "Durability Test Ended at: `date`"
