#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"        
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"

usage()
{
cat << EOF
usage: $0 -d <db>

The script runs TPC-H ACID Isolation Test #5

OPTIONS:
    -h              show this message
    -d  <database>  database name
    -f  <number>    database scale factor
EOF
}

DATABASE=
SF=
while getopts "d:f:" opt; do
    case $opt in
        d)
            DATABASE=$OPTARG
            ;;
        f)
            SF=$OPTARG
            ;;
        ?)
            usage
            exit 1
            ;;
    esac
done

if [ -z "$DATABASE" ]; then
    usage
    exit 1
fi

if [ -z "$SF" ]; then
    usage
    exit 1
fi

rm -f waiting

echo "==============================================================="
echo "TPC-H Isolation Test #5 started at `date`"
echo "==============================================================="
echo

# truncate HISTORY table
echo "Truncate the HISTORY table:"
echo "delete from HISTORY;\p\g" | sql $DATABASE

# create directory to store test-related data
#
OUTPUT_DIR="$IVWDIR/acid/iso/output"
mkdir -p $OUTPUT_DIR

# generate random values for Txn1
#
RAND_VALUES=`$IVWDIR/acid/acidkeys -b $DATABASE -c 1`
RAND_O_KEY=`echo $RAND_VALUES | awk '{printf $1}'`
RAND_L_KEY=`echo $RAND_VALUES | awk '{printf $2}'`
RAND_DELTA=`echo $RAND_VALUES | awk '{printf $3}'`

echo "Random values used for Txn1:"
echo "O_KEY  = $RAND_O_KEY"
echo "L_KEY  = $RAND_L_KEY"
echo "DELTA  = $RAND_DELTA"
echo

# Generate random values for Txn2 (PS_PARTKEY and PS_SUPPKEY)
#
RAND_VALUES2=`$IVWDIR/acid/pskeys -b $DATABASE -f $SF`
RAND_PS_PARTKEY=`echo $RAND_VALUES2 | awk '{printf $1}'`
RAND_PS_SUPPKEY=`echo $RAND_VALUES2 | awk '{printf $2}'`

echo "Random values used for Txn2:"
echo "RAND_PS_PARTKEY = $RAND_PS_PARTKEY"
echo "RAND_PS_SUPPKEY = $RAND_PS_SUPPKEY"

# Start an ACID txn and suspend for 40 seconds prior to COMMIT
# using RAND_O_KEY, RAND_L_KEY and RAND_DELTA
#
echo $RAND_VALUES | $IVWDIR/acid/acidtrans -b $DATABASE -s 40 | tee $OUTPUT_DIR/output_iso5_Txn1 2>&1 &

# wait for the acidtrans to wait
#
while [ 1 ];do
   sleep 1
   if [ -f waiting ]; then
        rm waiting
        sleep 1
        break;
   fi
done

# Start Txn2 
#
echo
echo ">> Transaction 2 started at `date`" 
echo

echo "select * from partsupp where ps_partkey = $RAND_PS_PARTKEY and ps_suppkey = $RAND_PS_SUPPKEY;\p\g" | sql $DATABASE | tee $OUTPUT_DIR/output_iso5_Txn2

echo
echo ">> Transaction 2 ended at `date`" 
echo

wait

# show HISTORY table
echo
echo "Contents of the HISTORY table:"
echo "select * from HISTORY;\p\g" | sql $DATABASE

echo
echo Verify files:
echo $OUTPUT_DIR/output_iso5_Txn1
echo $OUTPUT_DIR/output_iso5_Txn2

echo
echo "TPC-H Isolation Test #5 ended at `date`"
echo
