#!/bin/bash

# 
# This file is released under the terms of the Artistic License.
# Please see the file LICENSE, included in this package, for details.
#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"
source $TOPDIR/scripts/kit_profile || er "$0: could not source kit_profile"

unset SET_NUM
unset DATABASE
unset OUTPUT_DIR
unset DSS_PATH
unset PAR

while [ $# -ne 0 ]
do
    case $1 in
    -d)     shift;
            DATABASE=$1
        ;;
    -df)    shift;
            DSS_PATH=$1
        ;;
    -o)     shift;
            OUTPUT_DIR=$1
        ;;
    -s)     shift;
            SET_NUM=$1
        ;;
    -par)   shift;
            PAR=$1
        ;;
    *)      echo "Usage: $0"
            echo "     -d  <database> (required)"
            echo "     -df <data set directory> (required)" 
            echo "     -o  <output directory> (required)"
            echo "     -s  <data set number> (required)"
            echo "     -par  <number> parallelism for refresh load (required)"
            exit 1
            ;;
    esac
    shift
done

if [ -z ${DATABASE} ]; then
	er "database name is required."
fi
	
if [ -z ${DSS_PATH} ]; then
	er "updata data sets directory is required."
fi

if [ -z ${OUTPUT_DIR} ]; then
        er "output directory is required."
fi

if [ -z ${SET_NUM} ]; then
	er "data set number is required."
fi

if [ -z "$PAR" ]; then 
	er "parallelism for refresh data load, matching the refresh data dir contents is required"
fi

RFOUTPUT_DIR="$OUTPUT_DIR/results/rf2"
OUTPUT_FILE="$RFOUTPUT_DIR/setnum${SET_NUM}_output"
mkdir -p $RFOUTPUT_DIR
header="$IVWDIR/import/header"


#
# RF2
#

s_time_rf2=`$GTIME`
human_time=`echo $s_time_rf2 | $IVWDIR/unix2human.awk`
echo "RF2 (set #${SET_NUM}) - Start Time: $human_time" | tee -a $OUTPUT_FILE

# drop temp tables
cmd="\continue;\p\g drop table orderkeys_tmp; \p\g"
echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
           || er "could not drop temp table orderkeys_tmp  See $OUTPUT_FILE"
for ((p=1; p<=$PAR; p++));do
        cmd="\continue;\p\g drop table orderkeys_tmp_$p;\p\g"
        echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
                || er "could not drop table orderkeys_tmp_$p. See $OUTPUT_FILE"
done


# create temp table
cmd="create table orderkeys_tmp (orderkey bigint); \p\g"
echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
	   || er "could not create temporary table orderkeys_tmp. See $OUTPUT_FILE "
for ((p=1; p<=$PAR; p++));do
        cmd="create table orderkeys_tmp_$p (orderkey bigint); \p\g"
        echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
                || er "could not create table orderkeys_tmp_$p. See $OUTPUT_FILE"
done


# Load temporary table pieces
for ((p=1; p<=$PAR; p++));do
	copy_tmp="copy orderkeys_tmp_$p (orderkey = char(0)'|',nl=d1) from 'delete.u${SET_NUM}.$p'"
	pushd ${DSS_PATH} > /dev/null
	echo `cat $header` ${copy_tmp} '\p\g' | sql $DATABASE >> $OUTPUT_FILE \
	   || er "could not copy orderkeys_tmp_${p}. See $OUTPUT_FILE" &
	popd > /dev/null
done
wait

tmp=`mktemp`
# merege files
cp $header ${tmp}.sql
echo -n "insert into orderkeys_tmp select * from orderkeys_tmp_1 " >${tmp}.sql
for ((p=2; p<=$PAR; p++));do
        echo -n " union all select * from orderkeys_tmp_$p " >>${tmp}.sql
done
echo '\p\g' >>${tmp}.sql
sql <${tmp}.sql $DATABASE >>$OUTPUT_FILE \
        || er "could not merge pieces tables into table orderkeys_tmp . See $OUTPUT_FILE"
		 
# Run RF2 txn
echo "** Start of RF2 transaction" >> $OUTPUT_FILE
HEADER=`cat $IVWDIR/rf/header`
RF2=`cat $IVWDIR/rf/rf2.sql `
echo "$HEADER $RF2; commit;\nocontinue\p\g" | sql $DATABASE >> $OUTPUT_FILE \
    || er "RF2 txn failed. could not delete from orders/lineitem. See $OUTPUT_FILE"
echo "** End of RF2 transaction" >> $OUTPUT_FILE

# drop temp tables
cmd="\continue; drop table orderkeys_tmp; \p\g"
echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
           || er "could not drop temp table orderkeys_tmp.  See $OUTPUT_FILE"
for ((p=1; p<=$PAR; p++));do
        cmd="\continue; drop table orderkeys_tmp_$p;\p\g"
        echo "`cat $header` ${cmd}" | sql $DATABASE >> $OUTPUT_FILE \
                || er "could not drop table orderkeys_tmp_$p. See $OUTPUT_FILE"
done

# End RF2
e_time_rf2=`$GTIME`
human_time=`echo $e_time_rf2 | $IVWDIR/unix2human.awk`
echo "RF2 (set #${SET_NUM}) - End Time: $human_time" | tee -a $OUTPUT_FILE

diff_time=`echo "$s_time_rf2 $e_time_rf2" | awk '{printf("%.2f", $2 - $1);}'`

# Round duration of less than 0.05 to 0.1, then round it to the nearest tenth.
diff_time=`echo $diff_time | awk '{if ($1<0.05) $1=0.1; x=sprintf("%.1f", int($1*10+0.5)/10); printf(x)}'`

echo "RF2 (set #${SET_NUM}) - Duration: $diff_time seconds" | tee -a $OUTPUT_FILE

echo "RF2 $s_time_rf2 $e_time_rf2" > $RFOUTPUT_DIR/times${SET_NUM}
echo "RF2 (set #${SET_NUM}) - output ==> $OUTPUT_FILE"

