#!/bin/bash

#
# Copyright (c) 2010 Ingres Corp.
#

TOPDIR="`cat .topdir`"        
IVWDIR="$TOPDIR/scripts/ingres_vectorwise"
source $TOPDIR/scripts/kit_profile || er "$0: could not source kit_profile"

unset START_SET_NUM
unset END_SET_NUM
unset DATABASE
unset OUTPUT_DIR
unset DSS_PATH
unset PAR

while [ $# -ne 0 ]
do
    case $1 in
    -d)     shift;
            DATABASE=$1
        ;;
    -df)    shift;
            DSS_PATH=$1
        ;;
    -o)     shift;
            OUTPUT_DIR=$1
        ;;
    -ss)    shift;
            START_SET_NUM=$1
        ;;
    -es)    shift;
	    END_SET_NUM=$1
	;;
    -par)   shift;
	    PAR="-par $1"
	;;
    *)      echo "Usage: $0"
            echo "     -d    <database> (required)"
            echo "     -df   <data set directory> (required)" 
            echo "     -o    <output directory> (required)"
            echo "     -ss   <start data set number> (required)"
	    echo "     -es   <end data set number> (required)"
	    echo "     -par <number> parallelism for loading rf data (required)"
            exit 1
            ;;
    esac
    shift
done

if [ -z ${DATABASE} ]; then
	er "database name is required."
fi
	
if [ -z ${DSS_PATH} ]; then
	er "updata data sets directory is required."
fi

if [ -z ${OUTPUT_DIR} ]; then
        er "output directory is required."
fi

if [ -z ${START_SET_NUM} ]; then
	er "start data set number is required."
fi

if [ -z ${END_SET_NUM} ]; then
	er "end data set number is required"
fi

if [ ${START_SET_NUM} -gt ${END_SET_NUM} ]; then
	er "start data set number > end data set number"
fi

if [ -z "$PAR" ];then
	er "parallelism for refresh data laods was not specified"
fi

# start refresh stream
for i in `seq ${START_SET_NUM} ${END_SET_NUM}`; do
	# RF1
	$IVWDIR/run_rf1.sh -d ${DATABASE} -df ${DSS_PATH} -o ${OUTPUT_DIR} -s ${i} ${PAR} || er "RF1 failed"

	# RF2
	$IVWDIR/run_rf2.sh -d ${DATABASE} -df ${DSS_PATH} -o ${OUTPUT_DIR} -s ${i} ${PAR} || er "RF2 failed."

	# store last RF set number used
	echo ${i} > $IVWDIR/last_rfset_${DATABASE}
done
